@@ -26,7 +26,6 @@
  */
 
 #include <glib/gstdio.h>
-#include <GL/gl.h>
 
 #include <grits.h>
 
@@ -113,8 +112,8 @@ static guint16 *_load_bil(gchar *path)
 	g_file_get_contents(path, &data, &len, NULL);
 	g_debug("GritsPluginElev: load_bil %p", data);
 	if (len != TILE_SIZE) {
-		g_warning("GritsPluginElev: _load_bil - unexpected tile size %d, != %d",
-				len, TILE_SIZE);
+		g_warning("GritsPluginElev: _load_bil - unexpected tile size %ld, != %ld",
+				(glong)len, (glong)TILE_SIZE);
 		g_free(data);
 		return NULL;
 	}
@@ -301,7 +300,7 @@ GritsPluginElev *grits_plugin_elev_new(GritsViewer *viewer)
 
 	/* Add renderers */
 	if (LOAD_OPENGL)
-		grits_viewer_add(viewer, GRITS_OBJECT(elev->tiles), GRITS_LEVEL_WORLD, 0);
+		grits_viewer_add(viewer, GRITS_OBJECT(elev->tiles), GRITS_LEVEL_WORLD, FALSE);
 
 	return elev;
 }
