@@ -25,9 +25,6 @@
 
 #include <string.h>
 
-#include <GL/gl.h>
-#include <GL/glu.h>
-
 #include <gdk/gdkkeysyms.h>
 #include <grits.h>
 
@@ -35,21 +32,21 @@
 
 static void on_poly_enter(GritsPoly *poly)
 {
-	g_debug("on_poly_enter");
+	g_debug("GritsPluginTest: on_poly_enter");
 	poly->color[3] = 0.50;
 	grits_object_queue_draw(GRITS_OBJECT(poly));
 }
 
 static void on_poly_leave(GritsPoly *poly)
 {
-	g_debug("on_poly_leave");
+	g_debug("GritsPluginTest: on_poly_leave");
 	poly->color[3] = 0.2;
 	grits_object_queue_draw(GRITS_OBJECT(poly));
 }
 
 static void on_poly_button(GritsPoly *poly, GdkEventButton *event)
 {
-	g_debug("on_poly_button");
+	g_debug("GritsPluginTest: on_poly_button");
 	static int i = 0;
 	gdouble colors[][3] = {
 		{1, 0, 0}, {1, 1, 0},
@@ -63,12 +60,14 @@ static void on_poly_button(GritsPoly *poly, GdkEventButton *event)
 
 static void on_poly_key(GritsPoly *poly, GdkEventKey *event)
 {
-	g_debug("on_poly_key");
+	g_debug("GritsPluginTest: on_poly_key - %d", event->keyval);
 	gdouble colors[0xff][3] = {
 		[GDK_r] {1, 0, 0},
 		[GDK_g] {0, 1, 0},
 		[GDK_b] {0, 0, 1},
 	};
+	if (event->keyval >= G_N_ELEMENTS(colors))
+		return;
 	int key = event->keyval;
 	memcpy(poly->color, colors[key], sizeof(gdouble)*3);
 	grits_object_queue_draw(GRITS_OBJECT(poly));
@@ -76,7 +75,7 @@ static void on_poly_key(GritsPoly *poly, GdkEventKey *event)
 
 static void on_marker_enter(GritsMarker *marker, GritsViewer *viewer)
 {
-	g_debug("on_marker_enter");
+	g_debug("GritsPluginTest: on_marker_enter");
 	GdkWindow *window = gtk_widget_get_window(GTK_WIDGET(viewer));
 	GdkCursor *cursor = gdk_cursor_new(GDK_HAND1);
 	gdk_window_set_cursor(window, cursor);
@@ -84,14 +83,14 @@ static void on_marker_enter(GritsMarker *marker, GritsViewer *viewer)
 
 static void on_marker_leave(GritsMarker *marker, GritsViewer *viewer)
 {
-	g_debug("on_marker_leave");
+	g_debug("GritsPluginTest: on_marker_leave");
 	GdkWindow *window = gtk_widget_get_window(GTK_WIDGET(viewer));
 	gdk_window_set_cursor(window, NULL);
 }
 
 static void on_marker_button(GritsMarker *marker, GdkEventButton *event)
 {
-	g_debug("on_marker_button");
+	g_debug("GritsPluginTest: on_marker_button");
 	GtkWidget *dialog = gtk_dialog_new_with_buttons(
 			"St. Charles!", NULL, 0, GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 	gtk_dialog_run(GTK_DIALOG(dialog));
@@ -106,7 +105,7 @@ void _load_marker(GritsPluginTest *test)
 	GRITS_OBJECT(test->marker)->center.lat  =  38.841847;
 	GRITS_OBJECT(test->marker)->center.lon  = -90.491982;
 	GRITS_OBJECT(test->marker)->center.elev =   0.0;
-	GRITS_OBJECT(test->marker)->lod         = EARTH_R;
+	GRITS_OBJECT(test->marker)->lod         = EARTH_R*3;
 	grits_viewer_add(test->viewer, GRITS_OBJECT(test->marker), GRITS_LEVEL_OVERLAY, FALSE);
 	/* These do not work on marker yet */
 	//g_signal_connect(test->marker, "enter",        G_CALLBACK(on_marker_enter),  NULL);
@@ -126,13 +125,28 @@ void _load_poly(GritsPluginTest *test)
 	test->poly->color[3]  = 0.2;
 	test->poly->border[3] = 1;
 	test->poly->width     = 6;
-	grits_viewer_add(test->viewer, GRITS_OBJECT(test->poly),  GRITS_LEVEL_OVERLAY, TRUE);
+	grits_viewer_add(test->viewer, GRITS_OBJECT(test->poly),  GRITS_LEVEL_OVERLAY, FALSE);
 	g_signal_connect(test->poly, "enter",        G_CALLBACK(on_poly_enter),  NULL);
 	g_signal_connect(test->poly, "leave",        G_CALLBACK(on_poly_leave),  NULL);
 	g_signal_connect(test->poly, "button-press", G_CALLBACK(on_poly_button), NULL);
 	g_signal_connect(test->poly, "key-press",    G_CALLBACK(on_poly_key),    NULL);
 }
 
+void _load_line(GritsPluginTest *test)
+{
+	test->line = grits_line_parse("30,-80 30,-120 50,-120 50,-80", "\t", " ", ",");
+	test->line->color[0]  = 1;
+	test->line->color[1]  = 0;
+	test->line->color[2]  = 0;
+	test->line->color[3]  = 1;
+	test->line->width     = 8;
+	grits_viewer_add(test->viewer, GRITS_OBJECT(test->line),  GRITS_LEVEL_OVERLAY, FALSE);
+	g_signal_connect(test->line, "enter",        G_CALLBACK(on_poly_enter),  NULL);
+	g_signal_connect(test->line, "leave",        G_CALLBACK(on_poly_leave),  NULL);
+	g_signal_connect(test->line, "button-press", G_CALLBACK(on_poly_button), NULL);
+	g_signal_connect(test->line, "key-press",    G_CALLBACK(on_poly_key),    NULL);
+}
+
 /**
  * grits_plugin_test_new:
  * @viewer: the #GritsViewer to use for drawing
@@ -148,6 +162,7 @@ GritsPluginTest *grits_plugin_test_new(GritsViewer *viewer)
 	test->viewer = g_object_ref(viewer);
 	_load_marker(test);
 	_load_poly(test);
+	_load_line(test);
 	return test;
 }
 
@@ -176,6 +191,8 @@ static void grits_plugin_test_dispose(GObject *_test)
 	GritsPluginTest *test = GRITS_PLUGIN_TEST(_test);
 	if (test->viewer) {
 		grits_viewer_remove(test->viewer, GRITS_OBJECT(test->marker));
+		grits_viewer_remove(test->viewer, GRITS_OBJECT(test->poly));
+		grits_viewer_remove(test->viewer, GRITS_OBJECT(test->line));
 		g_object_unref(test->viewer);
 		test->viewer = NULL;
 	}
